"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const _ = require("underscore");
const validators = require("./validators");
const dotty = require('dotty');
function params(options) {
    const mappedOptions = _.map(options, (v, key) => {
        const vs = _.flatten([v]);
        if (key.startsWith('!')) {
            vs.push(validators.required);
            key = key.substring(1);
        }
        return { key, validators: vs };
    });
    return async (ctx, next) => {
        ctx.errors = [];
        for (const o of mappedOptions) {
            const value = dotty.get(ctx.request, o.key);
            for (const fn of o.validators) {
                const pass = fn(ctx, o.key, value);
                if (!pass) {
                    ctx.errors.push({
                        path: o.key,
                        value,
                        failed: fn.name,
                    });
                }
            }
        }
        if (!_.isEmpty(ctx.errors)) {
            ctx.body = { errors: ctx.errors };
            ctx.status = 422;
        }
        else {
            await next();
        }
    };
}
exports.params = params;

//# sourceMappingURL=params.js.map
